@@ -33,7 +33,7 @@ class ImportRecord:
         source: ImportString,
         name: str = "",
         alias: str = "",
-        min_version: tuple[int, ...] = (3, 8),
+        min_version: tuple[int, ...] | None = (3, 8),
         fallback: _R | None = None,
     ) -> None:
         self.source = source
@@ -174,3 +174,9 @@ class ImportRecord:
             return True
 
         return False
+
+    def needs_sys_fallback(self) -> bool:
+        """
+        Whether ImportString requires `sys` module.
+        """
+        return True if (self.fallback and self.min_version) else False
